@@ -36,7 +36,10 @@ class DieselGenerator(Generator):
         else:
             if self.inputs.p_set_kw != 0:
                 nstate.p_kw = max(
-                    min(abs(self.inputs.p_set_kw), self.config.p_max_kw),
+                    min(
+                        abs(self.inputs.p_set_kw),
+                        self.config.p_max_kw,
+                    ),
                     self.config.p_min_kw,
                 )
             else:
