@@ -2,5 +2,4 @@ from pysimmods.model.state import ModelState
 
 
 class DieselGenState(ModelState):
-    def __init__(self, inits):
-        super().__init__(inits)
+    """State of the Diesel generator."""
