@@ -294,3 +294,8 @@ class Model(ABC):
         else:
             # Unit is off or does not follow primary purpose
             return 0
+
+    def get_default_setpoint(self, hour: int) -> float:
+        """Return the value of the default schedule at *hour*"""
+        hour = max(0, min(23, hour))
+        return self.config.default_schedule[hour]
