@@ -10,7 +10,9 @@ import mosaik_api
 import numpy as np
 import pandas as pd
 from pysimmods.mosaik import LOG
-from pysimmods.other.flexibility.flexibility_model import FlexibilityModel
+from pysimmods.other.flexibility.flexibility_model import (
+    FlexibilityModel,
+)
 from pysimmods.other.flexibility.forecast_model import ForecastModel
 from pysimmods.other.flexibility.schedule_model import ScheduleModel
 from pysimmods.util.date_util import GER
@@ -267,6 +269,16 @@ class FlexibilitySimulator(mosaik_api.Simulator):
                             self.models[eid].update_schedule(schedule)
                     continue
 
+                elif attr == "local_time":
+                    # Use time information from time generator
+                    for val in src_ids.values():
+                        self.models[eid].set_now_dt(val)
+                        self.now_dt = datetime.strptime(val, GER).astimezone(
+                            timezone.utc
+                        )
+                        break
+                    continue
+
                 # Aggregate inputs from different sources
                 attr_sum = 0
                 for src_id, val in src_ids.items():
