@@ -1,8 +1,8 @@
 """This module contains the state information of the heat demand model.
 """
 
-from datetime import datetime, timedelta
-from pysimmods.util.dateformat import GER
+from datetime import datetime
+from pysimmods.util.date_util import GER
 
 
 class HeatDemandState:
